==> mule-soap-engine-1.3.5-sources.jar: org/mule/soap/api/SoapWebServiceConfiguration.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.soap.api;

import org.mule.soap.api.security.SecurityStrategy;
import org.mule.soap.api.transport.locator.TransportResourceLocator;

import java.util.List;

/**
 * Represents a Soap Client Configuration with all the required attributes for stablishing a connection with the Web Service.
 *
 * @since 1.0
 */
public final class SoapWebServiceConfiguration {

  private final String wsdlLocation;
  private final String address;
  private final String service;
  private final String port;
  private final SoapVersion version;
  private final boolean mtomEnabled;
  private final List<SecurityStrategy> securities;
  private final TransportResourceLocator locator;
  private final String encoding;

  SoapWebServiceConfiguration(String wsdlLocation,
                              String address,
                              String service,
                              String port,
                              SoapVersion version,
                              boolean mtomEnabled,
                              List<SecurityStrategy> securities,
                              TransportResourceLocator locator,
                              String encoding) {
    this.wsdlLocation = wsdlLocation;
    this.address = address;
    this.service = service;
    this.port = port;
    this.version = version;
    this.mtomEnabled = mtomEnabled;
    this.securities = securities;
    this.locator = locator;
    this.encoding = encoding;
  }

  public static SoapWebServiceConfigurationBuilder builder() {
    return new SoapWebServiceConfigurationBuilder();
  }

  public String getWsdlLocation() {
    return wsdlLocation;
  }

  public String getAddress() {
    return address;
  }

  public String getService() {
    return service;
  }

  public String getPort() {
    return port;
  }

  public SoapVersion getVersion() {
    return version;
  }

  public boolean isMtomEnabled() {
    return mtomEnabled;
  }

  public List<SecurityStrategy> getSecurities() {
    return securities;
  }

  public String getEncoding() {
    return encoding == null ? "UTF-8" : encoding;
  }

  public TransportResourceLocator getLocator() {
    return locator;
  }
}

==> mule-soap-engine-1.5.0-sources.jar: org/mule/soap/api/SoapWebServiceConfiguration.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.soap.api;

import org.mule.soap.api.security.SecurityStrategy;
import org.mule.soap.api.transport.locator.TransportResourceLocator;

import java.util.List;

/**
 * Represents a Soap Client Configuration with all the required attributes for stablishing a connection with the Web Service.
 *
 * @since 1.0
 */
public final class SoapWebServiceConfiguration {

  private final String wsdlLocation;
  private final String address;
  private final String service;
  private final String port;
  private final SoapVersion version;
  private final boolean mtomEnabled;
  private final List<SecurityStrategy> securities;
  private final TransportResourceLocator locator;
  private final String encoding;
  private final boolean includeRMOperations;

  SoapWebServiceConfiguration(String wsdlLocation,
                              String address,
                              String service,
                              String port,
                              SoapVersion version,
                              boolean mtomEnabled,
                              List<SecurityStrategy> securities,
                              TransportResourceLocator locator,
                              String encoding) {
    this(wsdlLocation, address, service, port, version, mtomEnabled, securities, locator, encoding, false);
  }

  SoapWebServiceConfiguration(String wsdlLocation,
                              String address,
                              String service,
                              String port,
                              SoapVersion version,
                              boolean mtomEnabled,
                              List<SecurityStrategy> securities,
                              TransportResourceLocator locator,
                              String encoding,
                              boolean includeRMOperations) {
    this.wsdlLocation = wsdlLocation;
    this.address = address;
    this.service = service;
    this.port = port;
    this.version = version;
    this.mtomEnabled = mtomEnabled;
    this.securities = securities;
    this.locator = locator;
    this.encoding = encoding;
    this.includeRMOperations = includeRMOperations;
  }

  public static SoapWebServiceConfigurationBuilder builder() {
    return new SoapWebServiceConfigurationBuilder();
  }

  public String getWsdlLocation() {
    return wsdlLocation;
  }

  public String getAddress() {
    return address;
  }

  public String getService() {
    return service;
  }

  public String getPort() {
    return port;
  }

  public SoapVersion getVersion() {
    return version;
  }

  public boolean isMtomEnabled() {
    return mtomEnabled;
  }

  public List<SecurityStrategy> getSecurities() {
    return securities;
  }

  public String getEncoding() {
    return encoding == null ? "UTF-8" : encoding;
  }

  public TransportResourceLocator getLocator() {
    return locator;
  }

  /**
   * {@code true} if the Reliable Messaging operations must be included, {@code false} otherwise.
   *
   * @since 1.5
   */
  public boolean includeRMOperations() {
    return includeRMOperations;
  }
}
